package
Version:
v0.0.0-...-fe244b6
Opens a new window with list of versions in this module.
Published: Dec 25, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Block struct {
LastLine int
Stats []Stat
}
type CellStat struct {
Line int
Cell int
}
type IfStat struct {
Line int
Type int
}
type LoopStat struct {
Line int
Stats []Stat
}
type PointerStat struct {
Line int
Pointer int
}
type RegStat struct {
Line int
Reg int
}
stat ::= Assignment | Print | label | break | goto Name | if exp then block "elseif exp then block"* "else block"? end
type StringExp struct {
Line int
Str string
}
LiteralString
type Variable struct {
Line int
Name string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.